@@ -5,15 +5,18 @@
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation
-#
+
 # TODO: Include presets, saving and loading.
 
 from gi.repository import Gtk
 
+from quodlibet import _
 from quodlibet import app
 from quodlibet import config
 from quodlibet.qltk import Button, Icons
 from quodlibet.plugins.events import EventPlugin
+from quodlibet.compat import iteritems
+
 
 # Presets taken from pulseaudio equalizer
 PRESET_BANDS = [50, 100, 156, 220, 311, 440, 622, 880, 1250, 1750, 2500,
@@ -167,7 +170,7 @@ class Equalizer(EventPlugin):
         def clicked_cb(button):
             [adj.set_value(0) for adj in adjustments]
 
-        sorted_presets = sorted(PRESETS.iteritems())
+        sorted_presets = sorted(iteritems(PRESETS))
 
         def combo_changed(combo):
             # custom, skip
