@@ -27,7 +27,10 @@ except ImportError as e:
     raise (plugins.MissingModulePluginException("zeitgeist") if
            hasattr(plugins, "MissingModulePluginException") else e)
 
+from quodlibet import _
+from quodlibet.qltk import Icons
 from quodlibet.plugins.events import EventPlugin
+from quodlibet.util import print_d
 
 
 class Zeitgeist(EventPlugin):
@@ -35,7 +38,7 @@ class Zeitgeist(EventPlugin):
     PLUGIN_NAME = _("Event Logging")
     PLUGIN_DESC = _("Sends song events to the Zeitgeist event logging "
                     "service.")
-    PLUGIN_ICON = 'gtk-network'
+    PLUGIN_ICON = Icons.NETWORK_WORKGROUP
 
     def enabled(self):
         self.client = ZeitgeistClient()
